"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GameServicesGameServerClusterXConnectionInfoXGkeClusterReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    cluster: builtins.str
    def __init__(
        self,
        *,
        cluster: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster", b"cluster"]) -> None: ...

global___GameServicesGameServerClusterXConnectionInfoXGkeClusterReference = GameServicesGameServerClusterXConnectionInfoXGkeClusterReference

@typing_extensions.final
class GameServicesGameServerClusterXConnectionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_FIELD_NUMBER: builtins.int
    GKE_CLUSTER_REFERENCE_FIELD_NUMBER: builtins.int
    namespace: builtins.str
    @property
    def gke_cluster_reference(self) -> global___GameServicesGameServerClusterXConnectionInfoXGkeClusterReference: ...
    def __init__(
        self,
        *,
        namespace: builtins.str = ...,
        gke_cluster_reference: global___GameServicesGameServerClusterXConnectionInfoXGkeClusterReference | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gke_cluster_reference", b"gke_cluster_reference"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["gke_cluster_reference", b"gke_cluster_reference", "namespace", b"namespace"]) -> None: ...

global___GameServicesGameServerClusterXConnectionInfo = GameServicesGameServerClusterXConnectionInfo

@typing_extensions.final
class GameServicesGameServerClusterXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___GameServicesGameServerClusterXTimeouts = GameServicesGameServerClusterXTimeouts

@typing_extensions.final
class GameServicesGameServerCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REALM_ID_FIELD_NUMBER: builtins.int
    CONNECTION_INFO_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    description: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    project: builtins.str
    realm_id: builtins.str
    @property
    def connection_info(self) -> global___GameServicesGameServerClusterXConnectionInfo: ...
    @property
    def timeouts(self) -> global___GameServicesGameServerClusterXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        realm_id: builtins.str = ...,
        connection_info: global___GameServicesGameServerClusterXConnectionInfo | None = ...,
        timeouts: global___GameServicesGameServerClusterXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connection_info", b"connection_info", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id", "connection_info", b"connection_info", "description", b"description", "id", b"id", "labels", b"labels", "location", b"location", "name", b"name", "project", b"project", "realm_id", b"realm_id", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___GameServicesGameServerCluster = GameServicesGameServerCluster

@typing_extensions.final
class GameServicesGameServerConfigXFleetConfigs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FLEET_SPEC_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    fleet_spec: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        fleet_spec: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fleet_spec", b"fleet_spec", "name", b"name"]) -> None: ...

global___GameServicesGameServerConfigXFleetConfigs = GameServicesGameServerConfigXFleetConfigs

@typing_extensions.final
class GameServicesGameServerConfigXScalingConfigsXSchedules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CRON_JOB_DURATION_FIELD_NUMBER: builtins.int
    CRON_SPEC_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    cron_job_duration: builtins.str
    cron_spec: builtins.str
    end_time: builtins.str
    start_time: builtins.str
    def __init__(
        self,
        *,
        cron_job_duration: builtins.str = ...,
        cron_spec: builtins.str = ...,
        end_time: builtins.str = ...,
        start_time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cron_job_duration", b"cron_job_duration", "cron_spec", b"cron_spec", "end_time", b"end_time", "start_time", b"start_time"]) -> None: ...

global___GameServicesGameServerConfigXScalingConfigsXSchedules = GameServicesGameServerConfigXScalingConfigsXSchedules

@typing_extensions.final
class GameServicesGameServerConfigXScalingConfigsXSelectors(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    LABELS_FIELD_NUMBER: builtins.int
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["labels", b"labels"]) -> None: ...

global___GameServicesGameServerConfigXScalingConfigsXSelectors = GameServicesGameServerConfigXScalingConfigsXSelectors

@typing_extensions.final
class GameServicesGameServerConfigXScalingConfigs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FLEET_AUTOSCALER_SPEC_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SCHEDULES_FIELD_NUMBER: builtins.int
    SELECTORS_FIELD_NUMBER: builtins.int
    fleet_autoscaler_spec: builtins.str
    name: builtins.str
    @property
    def schedules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GameServicesGameServerConfigXScalingConfigsXSchedules]: ...
    @property
    def selectors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GameServicesGameServerConfigXScalingConfigsXSelectors]: ...
    def __init__(
        self,
        *,
        fleet_autoscaler_spec: builtins.str = ...,
        name: builtins.str = ...,
        schedules: collections.abc.Iterable[global___GameServicesGameServerConfigXScalingConfigsXSchedules] | None = ...,
        selectors: collections.abc.Iterable[global___GameServicesGameServerConfigXScalingConfigsXSelectors] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fleet_autoscaler_spec", b"fleet_autoscaler_spec", "name", b"name", "schedules", b"schedules", "selectors", b"selectors"]) -> None: ...

global___GameServicesGameServerConfigXScalingConfigs = GameServicesGameServerConfigXScalingConfigs

@typing_extensions.final
class GameServicesGameServerConfigXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___GameServicesGameServerConfigXTimeouts = GameServicesGameServerConfigXTimeouts

@typing_extensions.final
class GameServicesGameServerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONFIG_ID_FIELD_NUMBER: builtins.int
    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    FLEET_CONFIGS_FIELD_NUMBER: builtins.int
    SCALING_CONFIGS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    config_id: builtins.str
    deployment_id: builtins.str
    description: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def fleet_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GameServicesGameServerConfigXFleetConfigs]: ...
    @property
    def scaling_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GameServicesGameServerConfigXScalingConfigs]: ...
    @property
    def timeouts(self) -> global___GameServicesGameServerConfigXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        config_id: builtins.str = ...,
        deployment_id: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        fleet_configs: collections.abc.Iterable[global___GameServicesGameServerConfigXFleetConfigs] | None = ...,
        scaling_configs: collections.abc.Iterable[global___GameServicesGameServerConfigXScalingConfigs] | None = ...,
        timeouts: global___GameServicesGameServerConfigXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_id", b"config_id", "deployment_id", b"deployment_id", "description", b"description", "fleet_configs", b"fleet_configs", "id", b"id", "labels", b"labels", "location", b"location", "name", b"name", "project", b"project", "resource_info", b"resource_info", "scaling_configs", b"scaling_configs", "timeouts", b"timeouts"]) -> None: ...

global___GameServicesGameServerConfig = GameServicesGameServerConfig

@typing_extensions.final
class GameServicesGameServerDeploymentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___GameServicesGameServerDeploymentXTimeouts = GameServicesGameServerDeploymentXTimeouts

@typing_extensions.final
class GameServicesGameServerDeployment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    deployment_id: builtins.str
    description: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def timeouts(self) -> global___GameServicesGameServerDeploymentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        deployment_id: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        timeouts: global___GameServicesGameServerDeploymentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_id", b"deployment_id", "description", b"description", "id", b"id", "labels", b"labels", "location", b"location", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___GameServicesGameServerDeployment = GameServicesGameServerDeployment

@typing_extensions.final
class GameServicesGameServerDeploymentRolloutXGameServerConfigOverridesXRealmsSelector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REALMS_FIELD_NUMBER: builtins.int
    @property
    def realms(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        realms: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["realms", b"realms"]) -> None: ...

global___GameServicesGameServerDeploymentRolloutXGameServerConfigOverridesXRealmsSelector = GameServicesGameServerDeploymentRolloutXGameServerConfigOverridesXRealmsSelector

@typing_extensions.final
class GameServicesGameServerDeploymentRolloutXGameServerConfigOverrides(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_VERSION_FIELD_NUMBER: builtins.int
    REALMS_SELECTOR_FIELD_NUMBER: builtins.int
    config_version: builtins.str
    @property
    def realms_selector(self) -> global___GameServicesGameServerDeploymentRolloutXGameServerConfigOverridesXRealmsSelector: ...
    def __init__(
        self,
        *,
        config_version: builtins.str = ...,
        realms_selector: global___GameServicesGameServerDeploymentRolloutXGameServerConfigOverridesXRealmsSelector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["realms_selector", b"realms_selector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_version", b"config_version", "realms_selector", b"realms_selector"]) -> None: ...

global___GameServicesGameServerDeploymentRolloutXGameServerConfigOverrides = GameServicesGameServerDeploymentRolloutXGameServerConfigOverrides

@typing_extensions.final
class GameServicesGameServerDeploymentRolloutXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___GameServicesGameServerDeploymentRolloutXTimeouts = GameServicesGameServerDeploymentRolloutXTimeouts

@typing_extensions.final
class GameServicesGameServerDeploymentRollout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_GAME_SERVER_CONFIG_FIELD_NUMBER: builtins.int
    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    GAME_SERVER_CONFIG_OVERRIDES_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    default_game_server_config: builtins.str
    deployment_id: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def game_server_config_overrides(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GameServicesGameServerDeploymentRolloutXGameServerConfigOverrides]: ...
    @property
    def timeouts(self) -> global___GameServicesGameServerDeploymentRolloutXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        default_game_server_config: builtins.str = ...,
        deployment_id: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        game_server_config_overrides: collections.abc.Iterable[global___GameServicesGameServerDeploymentRolloutXGameServerConfigOverrides] | None = ...,
        timeouts: global___GameServicesGameServerDeploymentRolloutXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_game_server_config", b"default_game_server_config", "deployment_id", b"deployment_id", "game_server_config_overrides", b"game_server_config_overrides", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___GameServicesGameServerDeploymentRollout = GameServicesGameServerDeploymentRollout

@typing_extensions.final
class GameServicesRealmXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___GameServicesRealmXTimeouts = GameServicesRealmXTimeouts

@typing_extensions.final
class GameServicesRealm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESCRIPTION_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REALM_ID_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    project: builtins.str
    realm_id: builtins.str
    time_zone: builtins.str
    @property
    def timeouts(self) -> global___GameServicesRealmXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        realm_id: builtins.str = ...,
        time_zone: builtins.str = ...,
        timeouts: global___GameServicesRealmXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "etag", b"etag", "id", b"id", "labels", b"labels", "location", b"location", "name", b"name", "project", b"project", "realm_id", b"realm_id", "resource_info", b"resource_info", "time_zone", b"time_zone", "timeouts", b"timeouts"]) -> None: ...

global___GameServicesRealm = GameServicesRealm



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_wafv2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x61ws/aws_wafv2.proto\x12\x15oak9.tython.aws.wafv2\x1a\x13shared/shared.proto\"\x84\x02\n\x05IPSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05scope\x18\x04 \x01(\t\x12\x1a\n\x12ip_address_version\x18\x05 \x01(\t\x12\x11\n\taddresses\x18\x06 \x03(\t\x12\x34\n\x04tags\x18\x07 \x03(\x0b\x32&.oak9.tython.aws.wafv2.IPSet.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa9\x02\n\x05WAFv2\x12,\n\x06ip_set\x18\x01 \x03(\x0b\x32\x1c.oak9.tython.aws.wafv2.IPSet\x12\x41\n\x11regex_pattern_set\x18\x02 \x03(\x0b\x32&.oak9.tython.aws.wafv2.RegexPatternSet\x12\x34\n\nrule_group\x18\x03 \x03(\x0b\x32 .oak9.tython.aws.wafv2.RuleGroup\x12\x30\n\tweb_a_c_l\x18\x04 \x01(\x0b\x32\x1d.oak9.tython.aws.wafv2.WebACL\x12G\n\x15web_a_c_l_association\x18\x05 \x03(\x0b\x32(.oak9.tython.aws.wafv2.WebACLAssociation\"\x8a\x02\n\x0fRegexPatternSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1f\n\x17regular_expression_list\x18\x04 \x03(\t\x12\r\n\x05scope\x18\x05 \x01(\t\x12>\n\x04tags\x18\x06 \x03(\x0b\x32\x30.oak9.tython.aws.wafv2.RegexPatternSet.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8c\x08\n\x15RuleGroupFieldToMatch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12U\n\rsingle_header\x18\x02 \x03(\x0b\x32>.oak9.tython.aws.wafv2.RuleGroupFieldToMatch.SingleHeaderEntry\x12\x64\n\x15single_query_argument\x18\x03 \x03(\x0b\x32\x45.oak9.tython.aws.wafv2.RuleGroupFieldToMatch.SingleQueryArgumentEntry\x12`\n\x13\x61ll_query_arguments\x18\x04 \x03(\x0b\x32\x43.oak9.tython.aws.wafv2.RuleGroupFieldToMatch.AllQueryArgumentsEntry\x12K\n\x08uri_path\x18\x05 \x03(\x0b\x32\x39.oak9.tython.aws.wafv2.RuleGroupFieldToMatch.UriPathEntry\x12S\n\x0cquery_string\x18\x06 \x03(\x0b\x32=.oak9.tython.aws.wafv2.RuleGroupFieldToMatch.QueryStringEntry\x12\x44\n\x04\x62ody\x18\x07 \x03(\x0b\x32\x36.oak9.tython.aws.wafv2.RuleGroupFieldToMatch.BodyEntry\x12H\n\x06method\x18\x08 \x03(\x0b\x32\x38.oak9.tython.aws.wafv2.RuleGroupFieldToMatch.MethodEntry\x1a\x33\n\x11SingleHeaderEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a:\n\x18SingleQueryArgumentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x38\n\x16\x41llQueryArgumentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cUriPathEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10QueryStringEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tBodyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bMethodEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n\x1bRuleGroupTextTransformation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08priority\x18\x02 \x01(\x05\"\xc2\x02\n\x1bRuleGroupByteMatchStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rsearch_string\x18\x02 \x01(\t\x12\x1c\n\x14search_string_base64\x18\x03 \x01(\t\x12\x44\n\x0e\x66ield_to_match\x18\x04 \x01(\x0b\x32,.oak9.tython.aws.wafv2.RuleGroupFieldToMatch\x12P\n\x14text_transformations\x18\x05 \x03(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupTextTransformation\x12\x1d\n\x15positional_constraint\x18\x06 \x01(\t\"\xee\x01\n\x1bRuleGroupSqliMatchStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\x0e\x66ield_to_match\x18\x02 \x01(\x0b\x32,.oak9.tython.aws.wafv2.RuleGroupFieldToMatch\x12P\n\x14text_transformations\x18\x03 \x03(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupTextTransformation\"\xed\x01\n\x1aRuleGroupXssMatchStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\x0e\x66ield_to_match\x18\x02 \x01(\x0b\x32,.oak9.tython.aws.wafv2.RuleGroupFieldToMatch\x12P\n\x14text_transformations\x18\x03 \x03(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupTextTransformation\"\x9e\x02\n RuleGroupSizeConstraintStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\x0e\x66ield_to_match\x18\x02 \x01(\x0b\x32,.oak9.tython.aws.wafv2.RuleGroupFieldToMatch\x12\x1b\n\x13\x63omparison_operator\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\x05\x12P\n\x14text_transformations\x18\x05 \x03(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupTextTransformation\"\x8c\x01\n!RuleGroupForwardedIPConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bheader_name\x18\x02 \x01(\t\x12\x19\n\x11\x66\x61llback_behavior\x18\x03 \x01(\t\"\xc3\x01\n\x1aRuleGroupGeoMatchStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rcountry_codes\x18\x02 \x03(\t\x12U\n\x13\x66orwarded_ip_config\x18\x03 \x01(\x0b\x32\x38.oak9.tython.aws.wafv2.RuleGroupForwardedIPConfiguration\"\xa3\x01\n&RuleGroupIPSetForwardedIPConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bheader_name\x18\x02 \x01(\t\x12\x19\n\x11\x66\x61llback_behavior\x18\x03 \x01(\t\x12\x10\n\x08position\x18\x04 \x01(\t\"\xcb\x01\n RuleGroupIPSetReferenceStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12\x61\n\x1aip_set_forwarded_ip_config\x18\x03 \x01(\x0b\x32=.oak9.tython.aws.wafv2.RuleGroupIPSetForwardedIPConfiguration\"\x8a\x02\n*RuleGroupRegexPatternSetReferenceStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12\x44\n\x0e\x66ield_to_match\x18\x03 \x01(\x0b\x32,.oak9.tython.aws.wafv2.RuleGroupFieldToMatch\x12P\n\x14text_transformations\x18\x04 \x03(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupTextTransformation\"\xc1\x05\n\x17RuleGroupStatementThree\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x14\x62yte_match_statement\x18\x02 \x01(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupByteMatchStatement\x12P\n\x14sqli_match_statement\x18\x03 \x01(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupSqliMatchStatement\x12N\n\x13xss_match_statement\x18\x04 \x01(\x0b\x32\x31.oak9.tython.aws.wafv2.RuleGroupXssMatchStatement\x12Z\n\x19size_constraint_statement\x18\x05 \x01(\x0b\x32\x37.oak9.tython.aws.wafv2.RuleGroupSizeConstraintStatement\x12N\n\x13geo_match_statement\x18\x06 \x01(\x0b\x32\x31.oak9.tython.aws.wafv2.RuleGroupGeoMatchStatement\x12[\n\x1aip_set_reference_statement\x18\x07 \x01(\x0b\x32\x37.oak9.tython.aws.wafv2.RuleGroupIPSetReferenceStatement\x12p\n%regex_pattern_set_reference_statement\x18\x08 \x01(\x0b\x32\x41.oak9.tython.aws.wafv2.RuleGroupRegexPatternSetReferenceStatement\"\xa9\x02\n\x1eRuleGroupRateBasedStatementTwo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x1a\n\x12\x61ggregate_key_type\x18\x03 \x01(\t\x12L\n\x14scope_down_statement\x18\x04 \x01(\x0b\x32..oak9.tython.aws.wafv2.RuleGroupStatementThree\x12U\n\x13\x66orwarded_ip_config\x18\x05 \x01(\x0b\x32\x38.oak9.tython.aws.wafv2.RuleGroupForwardedIPConfiguration\"\x97\x01\n\x18RuleGroupAndStatementTwo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x42\n\nstatements\x18\x02 \x03(\x0b\x32..oak9.tython.aws.wafv2.RuleGroupStatementThree\"\x96\x01\n\x17RuleGroupOrStatementTwo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x42\n\nstatements\x18\x02 \x03(\x0b\x32..oak9.tython.aws.wafv2.RuleGroupStatementThree\"\x96\x01\n\x18RuleGroupNotStatementTwo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\tstatement\x18\x02 \x01(\x0b\x32..oak9.tython.aws.wafv2.RuleGroupStatementThree\"\xea\x07\n\x15RuleGroupStatementTwo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x14\x62yte_match_statement\x18\x02 \x01(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupByteMatchStatement\x12P\n\x14sqli_match_statement\x18\x03 \x01(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupSqliMatchStatement\x12N\n\x13xss_match_statement\x18\x04 \x01(\x0b\x32\x31.oak9.tython.aws.wafv2.RuleGroupXssMatchStatement\x12Z\n\x19size_constraint_statement\x18\x05 \x01(\x0b\x32\x37.oak9.tython.aws.wafv2.RuleGroupSizeConstraintStatement\x12N\n\x13geo_match_statement\x18\x06 \x01(\x0b\x32\x31.oak9.tython.aws.wafv2.RuleGroupGeoMatchStatement\x12[\n\x1aip_set_reference_statement\x18\x07 \x01(\x0b\x32\x37.oak9.tython.aws.wafv2.RuleGroupIPSetReferenceStatement\x12p\n%regex_pattern_set_reference_statement\x18\x08 \x01(\x0b\x32\x41.oak9.tython.aws.wafv2.RuleGroupRegexPatternSetReferenceStatement\x12S\n\x14rate_based_statement\x18\t \x01(\x0b\x32\x35.oak9.tython.aws.wafv2.RuleGroupRateBasedStatementTwo\x12\x46\n\rand_statement\x18\n \x01(\x0b\x32/.oak9.tython.aws.wafv2.RuleGroupAndStatementTwo\x12\x44\n\x0cor_statement\x18\x0b \x01(\x0b\x32..oak9.tython.aws.wafv2.RuleGroupOrStatementTwo\x12\x46\n\rnot_statement\x18\x0c \x01(\x0b\x32/.oak9.tython.aws.wafv2.RuleGroupNotStatementTwo\"\xa7\x02\n\x1eRuleGroupRateBasedStatementOne\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x1a\n\x12\x61ggregate_key_type\x18\x03 \x01(\t\x12J\n\x14scope_down_statement\x18\x04 \x01(\x0b\x32,.oak9.tython.aws.wafv2.RuleGroupStatementTwo\x12U\n\x13\x66orwarded_ip_config\x18\x05 \x01(\x0b\x32\x38.oak9.tython.aws.wafv2.RuleGroupForwardedIPConfiguration\"\x95\x01\n\x18RuleGroupAndStatementOne\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12@\n\nstatements\x18\x02 \x03(\x0b\x32,.oak9.tython.aws.wafv2.RuleGroupStatementTwo\"\x94\x01\n\x17RuleGroupOrStatementOne\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12@\n\nstatements\x18\x02 \x03(\x0b\x32,.oak9.tython.aws.wafv2.RuleGroupStatementTwo\"\x94\x01\n\x18RuleGroupNotStatementOne\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12?\n\tstatement\x18\x02 \x01(\x0b\x32,.oak9.tython.aws.wafv2.RuleGroupStatementTwo\"\xea\x07\n\x15RuleGroupStatementOne\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x14\x62yte_match_statement\x18\x02 \x01(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupByteMatchStatement\x12P\n\x14sqli_match_statement\x18\x03 \x01(\x0b\x32\x32.oak9.tython.aws.wafv2.RuleGroupSqliMatchStatement\x12N\n\x13xss_match_statement\x18\x04 \x01(\x0b\x32\x31.oak9.tython.aws.wafv2.RuleGroupXssMatchStatement\x12Z\n\x19size_constraint_statement\x18\x05 \x01(\x0b\x32\x37.oak9.tython.aws.wafv2.RuleGroupSizeConstraintStatement\x12N\n\x13geo_match_statement\x18\x06 \x01(\x0b\x32\x31.oak9.tython.aws.wafv2.RuleGroupGeoMatchStatement\x12[\n\x1aip_set_reference_statement\x18\x07 \x01(\x0b\x32\x37.oak9.tython.aws.wafv2.RuleGroupIPSetReferenceStatement\x12p\n%regex_pattern_set_reference_statement\x18\x08 \x01(\x0b\x32\x41.oak9.tython.aws.wafv2.RuleGroupRegexPatternSetReferenceStatement\x12S\n\x14rate_based_statement\x18\t \x01(\x0b\x32\x35.oak9.tython.aws.wafv2.RuleGroupRateBasedStatementOne\x12\x46\n\rand_statement\x18\n \x01(\x0b\x32/.oak9.tython.aws.wafv2.RuleGroupAndStatementOne\x12\x44\n\x0cor_statement\x18\x0b \x01(\x0b\x32..oak9.tython.aws.wafv2.RuleGroupOrStatementOne\x12\x46\n\rnot_statement\x18\x0c \x01(\x0b\x32/.oak9.tython.aws.wafv2.RuleGroupNotStatementOne\"\xaa\x03\n\x13RuleGroupRuleAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\x05\x61llow\x18\x02 \x03(\x0b\x32\x35.oak9.tython.aws.wafv2.RuleGroupRuleAction.AllowEntry\x12\x44\n\x05\x62lock\x18\x03 \x03(\x0b\x32\x35.oak9.tython.aws.wafv2.RuleGroupRuleAction.BlockEntry\x12\x44\n\x05\x63ount\x18\x04 \x03(\x0b\x32\x35.oak9.tython.aws.wafv2.RuleGroupRuleAction.CountEntry\x1a,\n\nAllowEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nBlockEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nCountEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb0\x01\n\x19RuleGroupVisibilityConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12 \n\x18sampled_requests_enabled\x18\x02 \x01(\x08\x12#\n\x1b\x63loud_watch_metrics_enabled\x18\x03 \x01(\x08\x12\x13\n\x0bmetric_name\x18\x04 \x01(\t\"\xb2\x02\n\rRuleGroupRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08priority\x18\x03 \x01(\x05\x12?\n\tstatement\x18\x04 \x01(\x0b\x32,.oak9.tython.aws.wafv2.RuleGroupStatementOne\x12:\n\x06\x61\x63tion\x18\x05 \x01(\x0b\x32*.oak9.tython.aws.wafv2.RuleGroupRuleAction\x12K\n\x11visibility_config\x18\x06 \x01(\x0b\x32\x30.oak9.tython.aws.wafv2.RuleGroupVisibilityConfig\"\xf1\x02\n\tRuleGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x63\x61pacity\x18\x02 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\r\n\x05scope\x18\x05 \x01(\t\x12\x33\n\x05rules\x18\x06 \x03(\x0b\x32$.oak9.tython.aws.wafv2.RuleGroupRule\x12K\n\x11visibility_config\x18\x07 \x01(\x0b\x32\x30.oak9.tython.aws.wafv2.RuleGroupVisibilityConfig\x12\x38\n\x04tags\x18\x08 \x03(\x0b\x32*.oak9.tython.aws.wafv2.RuleGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x02\n\x13WebACLDefaultAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\x05\x61llow\x18\x02 \x03(\x0b\x32\x35.oak9.tython.aws.wafv2.WebACLDefaultAction.AllowEntry\x12\x44\n\x05\x62lock\x18\x03 \x03(\x0b\x32\x35.oak9.tython.aws.wafv2.WebACLDefaultAction.BlockEntry\x1a,\n\nAllowEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nBlockEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf4\x07\n\x12WebACLFieldToMatch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\rsingle_header\x18\x02 \x03(\x0b\x32;.oak9.tython.aws.wafv2.WebACLFieldToMatch.SingleHeaderEntry\x12\x61\n\x15single_query_argument\x18\x03 \x03(\x0b\x32\x42.oak9.tython.aws.wafv2.WebACLFieldToMatch.SingleQueryArgumentEntry\x12]\n\x13\x61ll_query_arguments\x18\x04 \x03(\x0b\x32@.oak9.tython.aws.wafv2.WebACLFieldToMatch.AllQueryArgumentsEntry\x12H\n\x08uri_path\x18\x05 \x03(\x0b\x32\x36.oak9.tython.aws.wafv2.WebACLFieldToMatch.UriPathEntry\x12P\n\x0cquery_string\x18\x06 \x03(\x0b\x32:.oak9.tython.aws.wafv2.WebACLFieldToMatch.QueryStringEntry\x12\x41\n\x04\x62ody\x18\x07 \x03(\x0b\x32\x33.oak9.tython.aws.wafv2.WebACLFieldToMatch.BodyEntry\x12\x45\n\x06method\x18\x08 \x03(\x0b\x32\x35.oak9.tython.aws.wafv2.WebACLFieldToMatch.MethodEntry\x1a\x33\n\x11SingleHeaderEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a:\n\x18SingleQueryArgumentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x38\n\x16\x41llQueryArgumentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cUriPathEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10QueryStringEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tBodyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bMethodEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"e\n\x18WebACLTextTransformation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08priority\x18\x02 \x01(\x05\"\xb9\x02\n\x18WebACLByteMatchStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rsearch_string\x18\x02 \x01(\t\x12\x1c\n\x14search_string_base64\x18\x03 \x01(\t\x12\x41\n\x0e\x66ield_to_match\x18\x04 \x01(\x0b\x32).oak9.tython.aws.wafv2.WebACLFieldToMatch\x12M\n\x14text_transformations\x18\x05 \x03(\x0b\x32/.oak9.tython.aws.wafv2.WebACLTextTransformation\x12\x1d\n\x15positional_constraint\x18\x06 \x01(\t\"\xe5\x01\n\x18WebACLSqliMatchStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\x0e\x66ield_to_match\x18\x02 \x01(\x0b\x32).oak9.tython.aws.wafv2.WebACLFieldToMatch\x12M\n\x14text_transformations\x18\x03 \x03(\x0b\x32/.oak9.tython.aws.wafv2.WebACLTextTransformation\"\xe4\x01\n\x17WebACLXssMatchStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\x0e\x66ield_to_match\x18\x02 \x01(\x0b\x32).oak9.tython.aws.wafv2.WebACLFieldToMatch\x12M\n\x14text_transformations\x18\x03 \x03(\x0b\x32/.oak9.tython.aws.wafv2.WebACLTextTransformation\"\x95\x02\n\x1dWebACLSizeConstraintStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\x0e\x66ield_to_match\x18\x02 \x01(\x0b\x32).oak9.tython.aws.wafv2.WebACLFieldToMatch\x12\x1b\n\x13\x63omparison_operator\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\x05\x12M\n\x14text_transformations\x18\x05 \x03(\x0b\x32/.oak9.tython.aws.wafv2.WebACLTextTransformation\"\x89\x01\n\x1eWebACLForwardedIPConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bheader_name\x18\x02 \x01(\t\x12\x19\n\x11\x66\x61llback_behavior\x18\x03 \x01(\t\"\xbd\x01\n\x17WebACLGeoMatchStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rcountry_codes\x18\x02 \x03(\t\x12R\n\x13\x66orwarded_ip_config\x18\x03 \x01(\x0b\x32\x35.oak9.tython.aws.wafv2.WebACLForwardedIPConfiguration\"[\n\x12WebACLExcludedRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xac\x01\n!WebACLRuleGroupReferenceStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12\x41\n\x0e\x65xcluded_rules\x18\x03 \x03(\x0b\x32).oak9.tython.aws.wafv2.WebACLExcludedRule\"\xa0\x01\n#WebACLIPSetForwardedIPConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bheader_name\x18\x02 \x01(\t\x12\x19\n\x11\x66\x61llback_behavior\x18\x03 \x01(\t\x12\x10\n\x08position\x18\x04 \x01(\t\"\xc5\x01\n\x1dWebACLIPSetReferenceStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12^\n\x1aip_set_forwarded_ip_config\x18\x03 \x01(\x0b\x32:.oak9.tython.aws.wafv2.WebACLIPSetForwardedIPConfiguration\"\x81\x02\n\'WebACLRegexPatternSetReferenceStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12\x41\n\x0e\x66ield_to_match\x18\x03 \x01(\x0b\x32).oak9.tython.aws.wafv2.WebACLFieldToMatch\x12M\n\x14text_transformations\x18\x04 \x03(\x0b\x32/.oak9.tython.aws.wafv2.WebACLTextTransformation\"\xc0\x01\n\x1fWebACLManagedRuleGroupStatement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bvendor_name\x18\x03 \x01(\t\x12\x41\n\x0e\x65xcluded_rules\x18\x04 \x03(\x0b\x32).oak9.tython.aws.wafv2.WebACLExcludedRule\"\xe9\x06\n\x14WebACLStatementThree\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x14\x62yte_match_statement\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.wafv2.WebACLByteMatchStatement\x12M\n\x14sqli_match_statement\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.wafv2.WebACLSqliMatchStatement\x12K\n\x13xss_match_statement\x18\x04 \x01(\x0b\x32..oak9.tython.aws.wafv2.WebACLXssMatchStatement\x12W\n\x19size_constraint_statement\x18\x05 \x01(\x0b\x32\x34.oak9.tython.aws.wafv2.WebACLSizeConstraintStatement\x12K\n\x13geo_match_statement\x18\x06 \x01(\x0b\x32..oak9.tython.aws.wafv2.WebACLGeoMatchStatement\x12`\n\x1erule_group_reference_statement\x18\x07 \x01(\x0b\x32\x38.oak9.tython.aws.wafv2.WebACLRuleGroupReferenceStatement\x12X\n\x1aip_set_reference_statement\x18\x08 \x01(\x0b\x32\x34.oak9.tython.aws.wafv2.WebACLIPSetReferenceStatement\x12m\n%regex_pattern_set_reference_statement\x18\t \x01(\x0b\x32>.oak9.tython.aws.wafv2.WebACLRegexPatternSetReferenceStatement\x12\\\n\x1cmanaged_rule_group_statement\x18\n \x01(\x0b\x32\x36.oak9.tython.aws.wafv2.WebACLManagedRuleGroupStatement\"\xa0\x02\n\x1bWebACLRateBasedStatementTwo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x1a\n\x12\x61ggregate_key_type\x18\x03 \x01(\t\x12I\n\x14scope_down_statement\x18\x04 \x01(\x0b\x32+.oak9.tython.aws.wafv2.WebACLStatementThree\x12R\n\x13\x66orwarded_ip_config\x18\x05 \x01(\x0b\x32\x35.oak9.tython.aws.wafv2.WebACLForwardedIPConfiguration\"\x91\x01\n\x15WebACLAndStatementTwo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12?\n\nstatements\x18\x02 \x03(\x0b\x32+.oak9.tython.aws.wafv2.WebACLStatementThree\"\x90\x01\n\x14WebACLOrStatementTwo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12?\n\nstatements\x18\x02 \x03(\x0b\x32+.oak9.tython.aws.wafv2.WebACLStatementThree\"\x90\x01\n\x15WebACLNotStatementTwo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12>\n\tstatement\x18\x02 \x01(\x0b\x32+.oak9.tython.aws.wafv2.WebACLStatementThree\"\x86\t\n\x12WebACLStatementTwo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x14\x62yte_match_statement\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.wafv2.WebACLByteMatchStatement\x12M\n\x14sqli_match_statement\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.wafv2.WebACLSqliMatchStatement\x12K\n\x13xss_match_statement\x18\x04 \x01(\x0b\x32..oak9.tython.aws.wafv2.WebACLXssMatchStatement\x12W\n\x19size_constraint_statement\x18\x05 \x01(\x0b\x32\x34.oak9.tython.aws.wafv2.WebACLSizeConstraintStatement\x12K\n\x13geo_match_statement\x18\x06 \x01(\x0b\x32..oak9.tython.aws.wafv2.WebACLGeoMatchStatement\x12`\n\x1erule_group_reference_statement\x18\x07 \x01(\x0b\x32\x38.oak9.tython.aws.wafv2.WebACLRuleGroupReferenceStatement\x12X\n\x1aip_set_reference_statement\x18\x08 \x01(\x0b\x32\x34.oak9.tython.aws.wafv2.WebACLIPSetReferenceStatement\x12m\n%regex_pattern_set_reference_statement\x18\t \x01(\x0b\x32>.oak9.tython.aws.wafv2.WebACLRegexPatternSetReferenceStatement\x12\\\n\x1cmanaged_rule_group_statement\x18\n \x01(\x0b\x32\x36.oak9.tython.aws.wafv2.WebACLManagedRuleGroupStatement\x12P\n\x14rate_based_statement\x18\x0b \x01(\x0b\x32\x32.oak9.tython.aws.wafv2.WebACLRateBasedStatementTwo\x12\x43\n\rand_statement\x18\x0c \x01(\x0b\x32,.oak9.tython.aws.wafv2.WebACLAndStatementTwo\x12\x41\n\x0cor_statement\x18\r \x01(\x0b\x32+.oak9.tython.aws.wafv2.WebACLOrStatementTwo\x12\x43\n\rnot_statement\x18\x0e \x01(\x0b\x32,.oak9.tython.aws.wafv2.WebACLNotStatementTwo\"\x9e\x02\n\x1bWebACLRateBasedStatementOne\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x1a\n\x12\x61ggregate_key_type\x18\x03 \x01(\t\x12G\n\x14scope_down_statement\x18\x04 \x01(\x0b\x32).oak9.tython.aws.wafv2.WebACLStatementTwo\x12R\n\x13\x66orwarded_ip_config\x18\x05 \x01(\x0b\x32\x35.oak9.tython.aws.wafv2.WebACLForwardedIPConfiguration\"\x8f\x01\n\x15WebACLAndStatementOne\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\nstatements\x18\x02 \x03(\x0b\x32).oak9.tython.aws.wafv2.WebACLStatementTwo\"\x8e\x01\n\x14WebACLOrStatementOne\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\nstatements\x18\x02 \x03(\x0b\x32).oak9.tython.aws.wafv2.WebACLStatementTwo\"\x8e\x01\n\x15WebACLNotStatementOne\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12<\n\tstatement\x18\x02 \x01(\x0b\x32).oak9.tython.aws.wafv2.WebACLStatementTwo\"\x86\t\n\x12WebACLStatementOne\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x14\x62yte_match_statement\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.wafv2.WebACLByteMatchStatement\x12M\n\x14sqli_match_statement\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.wafv2.WebACLSqliMatchStatement\x12K\n\x13xss_match_statement\x18\x04 \x01(\x0b\x32..oak9.tython.aws.wafv2.WebACLXssMatchStatement\x12W\n\x19size_constraint_statement\x18\x05 \x01(\x0b\x32\x34.oak9.tython.aws.wafv2.WebACLSizeConstraintStatement\x12K\n\x13geo_match_statement\x18\x06 \x01(\x0b\x32..oak9.tython.aws.wafv2.WebACLGeoMatchStatement\x12`\n\x1erule_group_reference_statement\x18\x07 \x01(\x0b\x32\x38.oak9.tython.aws.wafv2.WebACLRuleGroupReferenceStatement\x12X\n\x1aip_set_reference_statement\x18\x08 \x01(\x0b\x32\x34.oak9.tython.aws.wafv2.WebACLIPSetReferenceStatement\x12m\n%regex_pattern_set_reference_statement\x18\t \x01(\x0b\x32>.oak9.tython.aws.wafv2.WebACLRegexPatternSetReferenceStatement\x12\\\n\x1cmanaged_rule_group_statement\x18\n \x01(\x0b\x32\x36.oak9.tython.aws.wafv2.WebACLManagedRuleGroupStatement\x12P\n\x14rate_based_statement\x18\x0b \x01(\x0b\x32\x32.oak9.tython.aws.wafv2.WebACLRateBasedStatementOne\x12\x43\n\rand_statement\x18\x0c \x01(\x0b\x32,.oak9.tython.aws.wafv2.WebACLAndStatementOne\x12\x41\n\x0cor_statement\x18\r \x01(\x0b\x32+.oak9.tython.aws.wafv2.WebACLOrStatementOne\x12\x43\n\rnot_statement\x18\x0e \x01(\x0b\x32,.oak9.tython.aws.wafv2.WebACLNotStatementOne\"\x9e\x03\n\x10WebACLRuleAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\x05\x61llow\x18\x02 \x03(\x0b\x32\x32.oak9.tython.aws.wafv2.WebACLRuleAction.AllowEntry\x12\x41\n\x05\x62lock\x18\x03 \x03(\x0b\x32\x32.oak9.tython.aws.wafv2.WebACLRuleAction.BlockEntry\x12\x41\n\x05\x63ount\x18\x04 \x03(\x0b\x32\x32.oak9.tython.aws.wafv2.WebACLRuleAction.CountEntry\x1a,\n\nAllowEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nBlockEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nCountEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x02\n\x14WebACLOverrideAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x05\x63ount\x18\x02 \x03(\x0b\x32\x36.oak9.tython.aws.wafv2.WebACLOverrideAction.CountEntry\x12\x43\n\x04none\x18\x03 \x03(\x0b\x32\x35.oak9.tython.aws.wafv2.WebACLOverrideAction.NoneEntry\x1a,\n\nCountEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tNoneEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xad\x01\n\x16WebACLVisibilityConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12 \n\x18sampled_requests_enabled\x18\x02 \x01(\x08\x12#\n\x1b\x63loud_watch_metrics_enabled\x18\x03 \x01(\x08\x12\x13\n\x0bmetric_name\x18\x04 \x01(\t\"\xec\x02\n\nWebACLRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08priority\x18\x03 \x01(\x05\x12<\n\tstatement\x18\x04 \x01(\x0b\x32).oak9.tython.aws.wafv2.WebACLStatementOne\x12\x37\n\x06\x61\x63tion\x18\x05 \x01(\x0b\x32\'.oak9.tython.aws.wafv2.WebACLRuleAction\x12\x44\n\x0foverride_action\x18\x06 \x01(\x0b\x32+.oak9.tython.aws.wafv2.WebACLOverrideAction\x12H\n\x11visibility_config\x18\x07 \x01(\x0b\x32-.oak9.tython.aws.wafv2.WebACLVisibilityConfig\"\x8c\x04\n\x06WebACL\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x42\n\x0e\x64\x65\x66\x61ult_action\x18\x02 \x01(\x0b\x32*.oak9.tython.aws.wafv2.WebACLDefaultAction\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\r\n\x05scope\x18\x05 \x01(\t\x12\x30\n\x05rules\x18\x06 \x03(\x0b\x32!.oak9.tython.aws.wafv2.WebACLRule\x12H\n\x11visibility_config\x18\x07 \x01(\x0b\x32-.oak9.tython.aws.wafv2.WebACLVisibilityConfig\x12\x35\n\x04tags\x18\x08 \x03(\x0b\x32\'.oak9.tython.aws.wafv2.WebACL.TagsEntry\x12\x0b\n\x03\x61rn\x18\t \x01(\t\x12\x10\n\x08\x63\x61pacity\x18\n \x01(\t\x12\x17\n\x0flabel_namespace\x18\x0b \x01(\t\x12#\n\x1bmanaged_by_firewall_manager\x18\x0c \x01(\t\x12\x16\n\x0e\x63\x61ptcha_config\x18\r \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\x11WebACLAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\x12\x15\n\rweb_a_c_l_arn\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_wafv2_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IPSET_TAGSENTRY._options = None
  _IPSET_TAGSENTRY._serialized_options = b'8\001'
  _REGEXPATTERNSET_TAGSENTRY._options = None
  _REGEXPATTERNSET_TAGSENTRY._serialized_options = b'8\001'
  _RULEGROUPFIELDTOMATCH_SINGLEHEADERENTRY._options = None
  _RULEGROUPFIELDTOMATCH_SINGLEHEADERENTRY._serialized_options = b'8\001'
  _RULEGROUPFIELDTOMATCH_SINGLEQUERYARGUMENTENTRY._options = None
  _RULEGROUPFIELDTOMATCH_SINGLEQUERYARGUMENTENTRY._serialized_options = b'8\001'
  _RULEGROUPFIELDTOMATCH_ALLQUERYARGUMENTSENTRY._options = None
  _RULEGROUPFIELDTOMATCH_ALLQUERYARGUMENTSENTRY._serialized_options = b'8\001'
  _RULEGROUPFIELDTOMATCH_URIPATHENTRY._options = None
  _RULEGROUPFIELDTOMATCH_URIPATHENTRY._serialized_options = b'8\001'
  _RULEGROUPFIELDTOMATCH_QUERYSTRINGENTRY._options = None
  _RULEGROUPFIELDTOMATCH_QUERYSTRINGENTRY._serialized_options = b'8\001'
  _RULEGROUPFIELDTOMATCH_BODYENTRY._options = None
  _RULEGROUPFIELDTOMATCH_BODYENTRY._serialized_options = b'8\001'
  _RULEGROUPFIELDTOMATCH_METHODENTRY._options = None
  _RULEGROUPFIELDTOMATCH_METHODENTRY._serialized_options = b'8\001'
  _RULEGROUPRULEACTION_ALLOWENTRY._options = None
  _RULEGROUPRULEACTION_ALLOWENTRY._serialized_options = b'8\001'
  _RULEGROUPRULEACTION_BLOCKENTRY._options = None
  _RULEGROUPRULEACTION_BLOCKENTRY._serialized_options = b'8\001'
  _RULEGROUPRULEACTION_COUNTENTRY._options = None
  _RULEGROUPRULEACTION_COUNTENTRY._serialized_options = b'8\001'
  _RULEGROUP_TAGSENTRY._options = None
  _RULEGROUP_TAGSENTRY._serialized_options = b'8\001'
  _WEBACLDEFAULTACTION_ALLOWENTRY._options = None
  _WEBACLDEFAULTACTION_ALLOWENTRY._serialized_options = b'8\001'
  _WEBACLDEFAULTACTION_BLOCKENTRY._options = None
  _WEBACLDEFAULTACTION_BLOCKENTRY._serialized_options = b'8\001'
  _WEBACLFIELDTOMATCH_SINGLEHEADERENTRY._options = None
  _WEBACLFIELDTOMATCH_SINGLEHEADERENTRY._serialized_options = b'8\001'
  _WEBACLFIELDTOMATCH_SINGLEQUERYARGUMENTENTRY._options = None
  _WEBACLFIELDTOMATCH_SINGLEQUERYARGUMENTENTRY._serialized_options = b'8\001'
  _WEBACLFIELDTOMATCH_ALLQUERYARGUMENTSENTRY._options = None
  _WEBACLFIELDTOMATCH_ALLQUERYARGUMENTSENTRY._serialized_options = b'8\001'
  _WEBACLFIELDTOMATCH_URIPATHENTRY._options = None
  _WEBACLFIELDTOMATCH_URIPATHENTRY._serialized_options = b'8\001'
  _WEBACLFIELDTOMATCH_QUERYSTRINGENTRY._options = None
  _WEBACLFIELDTOMATCH_QUERYSTRINGENTRY._serialized_options = b'8\001'
  _WEBACLFIELDTOMATCH_BODYENTRY._options = None
  _WEBACLFIELDTOMATCH_BODYENTRY._serialized_options = b'8\001'
  _WEBACLFIELDTOMATCH_METHODENTRY._options = None
  _WEBACLFIELDTOMATCH_METHODENTRY._serialized_options = b'8\001'
  _WEBACLRULEACTION_ALLOWENTRY._options = None
  _WEBACLRULEACTION_ALLOWENTRY._serialized_options = b'8\001'
  _WEBACLRULEACTION_BLOCKENTRY._options = None
  _WEBACLRULEACTION_BLOCKENTRY._serialized_options = b'8\001'
  _WEBACLRULEACTION_COUNTENTRY._options = None
  _WEBACLRULEACTION_COUNTENTRY._serialized_options = b'8\001'
  _WEBACLOVERRIDEACTION_COUNTENTRY._options = None
  _WEBACLOVERRIDEACTION_COUNTENTRY._serialized_options = b'8\001'
  _WEBACLOVERRIDEACTION_NONEENTRY._options = None
  _WEBACLOVERRIDEACTION_NONEENTRY._serialized_options = b'8\001'
  _WEBACL_TAGSENTRY._options = None
  _WEBACL_TAGSENTRY._serialized_options = b'8\001'
  _IPSET._serialized_start=68
  _IPSET._serialized_end=328
  _IPSET_TAGSENTRY._serialized_start=285
  _IPSET_TAGSENTRY._serialized_end=328
  _WAFV2._serialized_start=331
  _WAFV2._serialized_end=628
  _REGEXPATTERNSET._serialized_start=631
  _REGEXPATTERNSET._serialized_end=897
  _REGEXPATTERNSET_TAGSENTRY._serialized_start=285
  _REGEXPATTERNSET_TAGSENTRY._serialized_end=328
  _RULEGROUPFIELDTOMATCH._serialized_start=900
  _RULEGROUPFIELDTOMATCH._serialized_end=1936
  _RULEGROUPFIELDTOMATCH_SINGLEHEADERENTRY._serialized_start=1575
  _RULEGROUPFIELDTOMATCH_SINGLEHEADERENTRY._serialized_end=1626
  _RULEGROUPFIELDTOMATCH_SINGLEQUERYARGUMENTENTRY._serialized_start=1628
  _RULEGROUPFIELDTOMATCH_SINGLEQUERYARGUMENTENTRY._serialized_end=1686
  _RULEGROUPFIELDTOMATCH_ALLQUERYARGUMENTSENTRY._serialized_start=1688
  _RULEGROUPFIELDTOMATCH_ALLQUERYARGUMENTSENTRY._serialized_end=1744
  _RULEGROUPFIELDTOMATCH_URIPATHENTRY._serialized_start=1746
  _RULEGROUPFIELDTOMATCH_URIPATHENTRY._serialized_end=1792
  _RULEGROUPFIELDTOMATCH_QUERYSTRINGENTRY._serialized_start=1794
  _RULEGROUPFIELDTOMATCH_QUERYSTRINGENTRY._serialized_end=1844
  _RULEGROUPFIELDTOMATCH_BODYENTRY._serialized_start=1846
  _RULEGROUPFIELDTOMATCH_BODYENTRY._serialized_end=1889
  _RULEGROUPFIELDTOMATCH_METHODENTRY._serialized_start=1891
  _RULEGROUPFIELDTOMATCH_METHODENTRY._serialized_end=1936
  _RULEGROUPTEXTTRANSFORMATION._serialized_start=1938
  _RULEGROUPTEXTTRANSFORMATION._serialized_end=2042
  _RULEGROUPBYTEMATCHSTATEMENT._serialized_start=2045
  _RULEGROUPBYTEMATCHSTATEMENT._serialized_end=2367
  _RULEGROUPSQLIMATCHSTATEMENT._serialized_start=2370
  _RULEGROUPSQLIMATCHSTATEMENT._serialized_end=2608
  _RULEGROUPXSSMATCHSTATEMENT._serialized_start=2611
  _RULEGROUPXSSMATCHSTATEMENT._serialized_end=2848
  _RULEGROUPSIZECONSTRAINTSTATEMENT._serialized_start=2851
  _RULEGROUPSIZECONSTRAINTSTATEMENT._serialized_end=3137
  _RULEGROUPFORWARDEDIPCONFIGURATION._serialized_start=3140
  _RULEGROUPFORWARDEDIPCONFIGURATION._serialized_end=3280
  _RULEGROUPGEOMATCHSTATEMENT._serialized_start=3283
  _RULEGROUPGEOMATCHSTATEMENT._serialized_end=3478
  _RULEGROUPIPSETFORWARDEDIPCONFIGURATION._serialized_start=3481
  _RULEGROUPIPSETFORWARDEDIPCONFIGURATION._serialized_end=3644
  _RULEGROUPIPSETREFERENCESTATEMENT._serialized_start=3647
  _RULEGROUPIPSETREFERENCESTATEMENT._serialized_end=3850
  _RULEGROUPREGEXPATTERNSETREFERENCESTATEMENT._serialized_start=3853
  _RULEGROUPREGEXPATTERNSETREFERENCESTATEMENT._serialized_end=4119
  _RULEGROUPSTATEMENTTHREE._serialized_start=4122
  _RULEGROUPSTATEMENTTHREE._serialized_end=4827
  _RULEGROUPRATEBASEDSTATEMENTTWO._serialized_start=4830
  _RULEGROUPRATEBASEDSTATEMENTTWO._serialized_end=5127
  _RULEGROUPANDSTATEMENTTWO._serialized_start=5130
  _RULEGROUPANDSTATEMENTTWO._serialized_end=5281
  _RULEGROUPORSTATEMENTTWO._serialized_start=5284
  _RULEGROUPORSTATEMENTTWO._serialized_end=5434
  _RULEGROUPNOTSTATEMENTTWO._serialized_start=5437
  _RULEGROUPNOTSTATEMENTTWO._serialized_end=5587
  _RULEGROUPSTATEMENTTWO._serialized_start=5590
  _RULEGROUPSTATEMENTTWO._serialized_end=6592
  _RULEGROUPRATEBASEDSTATEMENTONE._serialized_start=6595
  _RULEGROUPRATEBASEDSTATEMENTONE._serialized_end=6890
  _RULEGROUPANDSTATEMENTONE._serialized_start=6893
  _RULEGROUPANDSTATEMENTONE._serialized_end=7042
  _RULEGROUPORSTATEMENTONE._serialized_start=7045
  _RULEGROUPORSTATEMENTONE._serialized_end=7193
  _RULEGROUPNOTSTATEMENTONE._serialized_start=7196
  _RULEGROUPNOTSTATEMENTONE._serialized_end=7344
  _RULEGROUPSTATEMENTONE._serialized_start=7347
  _RULEGROUPSTATEMENTONE._serialized_end=8349
  _RULEGROUPRULEACTION._serialized_start=8352
  _RULEGROUPRULEACTION._serialized_end=8778
  _RULEGROUPRULEACTION_ALLOWENTRY._serialized_start=8642
  _RULEGROUPRULEACTION_ALLOWENTRY._serialized_end=8686
  _RULEGROUPRULEACTION_BLOCKENTRY._serialized_start=8688
  _RULEGROUPRULEACTION_BLOCKENTRY._serialized_end=8732
  _RULEGROUPRULEACTION_COUNTENTRY._serialized_start=8734
  _RULEGROUPRULEACTION_COUNTENTRY._serialized_end=8778
  _RULEGROUPVISIBILITYCONFIG._serialized_start=8781
  _RULEGROUPVISIBILITYCONFIG._serialized_end=8957
  _RULEGROUPRULE._serialized_start=8960
  _RULEGROUPRULE._serialized_end=9266
  _RULEGROUP._serialized_start=9269
  _RULEGROUP._serialized_end=9638
  _RULEGROUP_TAGSENTRY._serialized_start=285
  _RULEGROUP_TAGSENTRY._serialized_end=328
  _WEBACLDEFAULTACTION._serialized_start=9641
  _WEBACLDEFAULTACTION._serialized_end=9951
  _WEBACLDEFAULTACTION_ALLOWENTRY._serialized_start=8642
  _WEBACLDEFAULTACTION_ALLOWENTRY._serialized_end=8686
  _WEBACLDEFAULTACTION_BLOCKENTRY._serialized_start=8688
  _WEBACLDEFAULTACTION_BLOCKENTRY._serialized_end=8732
  _WEBACLFIELDTOMATCH._serialized_start=9954
  _WEBACLFIELDTOMATCH._serialized_end=10966
  _WEBACLFIELDTOMATCH_SINGLEHEADERENTRY._serialized_start=1575
  _WEBACLFIELDTOMATCH_SINGLEHEADERENTRY._serialized_end=1626
  _WEBACLFIELDTOMATCH_SINGLEQUERYARGUMENTENTRY._serialized_start=1628
  _WEBACLFIELDTOMATCH_SINGLEQUERYARGUMENTENTRY._serialized_end=1686
  _WEBACLFIELDTOMATCH_ALLQUERYARGUMENTSENTRY._serialized_start=1688
  _WEBACLFIELDTOMATCH_ALLQUERYARGUMENTSENTRY._serialized_end=1744
  _WEBACLFIELDTOMATCH_URIPATHENTRY._serialized_start=1746
  _WEBACLFIELDTOMATCH_URIPATHENTRY._serialized_end=1792
  _WEBACLFIELDTOMATCH_QUERYSTRINGENTRY._serialized_start=1794
  _WEBACLFIELDTOMATCH_QUERYSTRINGENTRY._serialized_end=1844
  _WEBACLFIELDTOMATCH_BODYENTRY._serialized_start=1846
  _WEBACLFIELDTOMATCH_BODYENTRY._serialized_end=1889
  _WEBACLFIELDTOMATCH_METHODENTRY._serialized_start=1891
  _WEBACLFIELDTOMATCH_METHODENTRY._serialized_end=1936
  _WEBACLTEXTTRANSFORMATION._serialized_start=10968
  _WEBACLTEXTTRANSFORMATION._serialized_end=11069
  _WEBACLBYTEMATCHSTATEMENT._serialized_start=11072
  _WEBACLBYTEMATCHSTATEMENT._serialized_end=11385
  _WEBACLSQLIMATCHSTATEMENT._serialized_start=11388
  _WEBACLSQLIMATCHSTATEMENT._serialized_end=11617
  _WEBACLXSSMATCHSTATEMENT._serialized_start=11620
  _WEBACLXSSMATCHSTATEMENT._serialized_end=11848
  _WEBACLSIZECONSTRAINTSTATEMENT._serialized_start=11851
  _WEBACLSIZECONSTRAINTSTATEMENT._serialized_end=12128
  _WEBACLFORWARDEDIPCONFIGURATION._serialized_start=12131
  _WEBACLFORWARDEDIPCONFIGURATION._serialized_end=12268
  _WEBACLGEOMATCHSTATEMENT._serialized_start=12271
  _WEBACLGEOMATCHSTATEMENT._serialized_end=12460
  _WEBACLEXCLUDEDRULE._serialized_start=12462
  _WEBACLEXCLUDEDRULE._serialized_end=12553
  _WEBACLRULEGROUPREFERENCESTATEMENT._serialized_start=12556
  _WEBACLRULEGROUPREFERENCESTATEMENT._serialized_end=12728
  _WEBACLIPSETFORWARDEDIPCONFIGURATION._serialized_start=12731
  _WEBACLIPSETFORWARDEDIPCONFIGURATION._serialized_end=12891
  _WEBACLIPSETREFERENCESTATEMENT._serialized_start=12894
  _WEBACLIPSETREFERENCESTATEMENT._serialized_end=13091
  _WEBACLREGEXPATTERNSETREFERENCESTATEMENT._serialized_start=13094
  _WEBACLREGEXPATTERNSETREFERENCESTATEMENT._serialized_end=13351
  _WEBACLMANAGEDRULEGROUPSTATEMENT._serialized_start=13354
  _WEBACLMANAGEDRULEGROUPSTATEMENT._serialized_end=13546
  _WEBACLSTATEMENTTHREE._serialized_start=13549
  _WEBACLSTATEMENTTHREE._serialized_end=14422
  _WEBACLRATEBASEDSTATEMENTTWO._serialized_start=14425
  _WEBACLRATEBASEDSTATEMENTTWO._serialized_end=14713
  _WEBACLANDSTATEMENTTWO._serialized_start=14716
  _WEBACLANDSTATEMENTTWO._serialized_end=14861
  _WEBACLORSTATEMENTTWO._serialized_start=14864
  _WEBACLORSTATEMENTTWO._serialized_end=15008
  _WEBACLNOTSTATEMENTTWO._serialized_start=15011
  _WEBACLNOTSTATEMENTTWO._serialized_end=15155
  _WEBACLSTATEMENTTWO._serialized_start=15158
  _WEBACLSTATEMENTTWO._serialized_end=16316
  _WEBACLRATEBASEDSTATEMENTONE._serialized_start=16319
  _WEBACLRATEBASEDSTATEMENTONE._serialized_end=16605
  _WEBACLANDSTATEMENTONE._serialized_start=16608
  _WEBACLANDSTATEMENTONE._serialized_end=16751
  _WEBACLORSTATEMENTONE._serialized_start=16754
  _WEBACLORSTATEMENTONE._serialized_end=16896
  _WEBACLNOTSTATEMENTONE._serialized_start=16899
  _WEBACLNOTSTATEMENTONE._serialized_end=17041
  _WEBACLSTATEMENTONE._serialized_start=17044
  _WEBACLSTATEMENTONE._serialized_end=18202
  _WEBACLRULEACTION._serialized_start=18205
  _WEBACLRULEACTION._serialized_end=18619
  _WEBACLRULEACTION_ALLOWENTRY._serialized_start=8642
  _WEBACLRULEACTION_ALLOWENTRY._serialized_end=8686
  _WEBACLRULEACTION_BLOCKENTRY._serialized_start=8688
  _WEBACLRULEACTION_BLOCKENTRY._serialized_end=8732
  _WEBACLRULEACTION_COUNTENTRY._serialized_start=8734
  _WEBACLRULEACTION_COUNTENTRY._serialized_end=8778
  _WEBACLOVERRIDEACTION._serialized_start=18622
  _WEBACLOVERRIDEACTION._serialized_end=18932
  _WEBACLOVERRIDEACTION_COUNTENTRY._serialized_start=8734
  _WEBACLOVERRIDEACTION_COUNTENTRY._serialized_end=8778
  _WEBACLOVERRIDEACTION_NONEENTRY._serialized_start=18889
  _WEBACLOVERRIDEACTION_NONEENTRY._serialized_end=18932
  _WEBACLVISIBILITYCONFIG._serialized_start=18935
  _WEBACLVISIBILITYCONFIG._serialized_end=19108
  _WEBACLRULE._serialized_start=19111
  _WEBACLRULE._serialized_end=19475
  _WEBACL._serialized_start=19478
  _WEBACL._serialized_end=20002
  _WEBACL_TAGSENTRY._serialized_start=285
  _WEBACL_TAGSENTRY._serialized_end=328
  _WEBACLASSOCIATION._serialized_start=20004
  _WEBACLASSOCIATION._serialized_end=20125
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ProjectXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    READ_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    read: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        read: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "read", b"read", "update", b"update"]) -> None: ...

global___ProjectXTimeouts = ProjectXTimeouts

@typing_extensions.final
class Project(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    AUTO_CREATE_NETWORK_FIELD_NUMBER: builtins.int
    BILLING_ACCOUNT_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NUMBER_FIELD_NUMBER: builtins.int
    ORG_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    SKIP_DELETE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    auto_create_network: builtins.bool
    billing_account: builtins.str
    folder_id: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    number: builtins.str
    org_id: builtins.str
    project_id: builtins.str
    skip_delete: builtins.bool
    @property
    def timeouts(self) -> global___ProjectXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        auto_create_network: builtins.bool = ...,
        billing_account: builtins.str = ...,
        folder_id: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        number: builtins.str = ...,
        org_id: builtins.str = ...,
        project_id: builtins.str = ...,
        skip_delete: builtins.bool = ...,
        timeouts: global___ProjectXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_create_network", b"auto_create_network", "billing_account", b"billing_account", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "number", b"number", "org_id", b"org_id", "project_id", b"project_id", "resource_info", b"resource_info", "skip_delete", b"skip_delete", "timeouts", b"timeouts"]) -> None: ...

global___Project = Project

@typing_extensions.final
class ProjectAccessApprovalSettingsXEnrolledServices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_PRODUCT_FIELD_NUMBER: builtins.int
    ENROLLMENT_LEVEL_FIELD_NUMBER: builtins.int
    cloud_product: builtins.str
    enrollment_level: builtins.str
    def __init__(
        self,
        *,
        cloud_product: builtins.str = ...,
        enrollment_level: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_product", b"cloud_product", "enrollment_level", b"enrollment_level"]) -> None: ...

global___ProjectAccessApprovalSettingsXEnrolledServices = ProjectAccessApprovalSettingsXEnrolledServices

@typing_extensions.final
class ProjectAccessApprovalSettingsXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ProjectAccessApprovalSettingsXTimeouts = ProjectAccessApprovalSettingsXTimeouts

@typing_extensions.final
class ProjectAccessApprovalSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVE_KEY_VERSION_FIELD_NUMBER: builtins.int
    ANCESTOR_HAS_ACTIVE_KEY_VERSION_FIELD_NUMBER: builtins.int
    ENROLLED_ANCESTOR_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INVALID_KEY_VERSION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NOTIFICATION_EMAILS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    ENROLLED_SERVICES_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    active_key_version: builtins.str
    ancestor_has_active_key_version: builtins.bool
    enrolled_ancestor: builtins.bool
    id: builtins.str
    invalid_key_version: builtins.bool
    name: builtins.str
    @property
    def notification_emails(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    project_id: builtins.str
    @property
    def enrolled_services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProjectAccessApprovalSettingsXEnrolledServices]: ...
    @property
    def timeouts(self) -> global___ProjectAccessApprovalSettingsXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        active_key_version: builtins.str = ...,
        ancestor_has_active_key_version: builtins.bool = ...,
        enrolled_ancestor: builtins.bool = ...,
        id: builtins.str = ...,
        invalid_key_version: builtins.bool = ...,
        name: builtins.str = ...,
        notification_emails: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        project_id: builtins.str = ...,
        enrolled_services: collections.abc.Iterable[global___ProjectAccessApprovalSettingsXEnrolledServices] | None = ...,
        timeouts: global___ProjectAccessApprovalSettingsXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["active_key_version", b"active_key_version", "ancestor_has_active_key_version", b"ancestor_has_active_key_version", "enrolled_ancestor", b"enrolled_ancestor", "enrolled_services", b"enrolled_services", "id", b"id", "invalid_key_version", b"invalid_key_version", "name", b"name", "notification_emails", b"notification_emails", "project", b"project", "project_id", b"project_id", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ProjectAccessApprovalSettings = ProjectAccessApprovalSettings

@typing_extensions.final
class ProjectDefaultServiceAccountsXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    READ_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    read: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        read: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "read", b"read"]) -> None: ...

global___ProjectDefaultServiceAccountsXTimeouts = ProjectDefaultServiceAccountsXTimeouts

@typing_extensions.final
class ProjectDefaultServiceAccounts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ServiceAccountsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ACTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESTORE_POLICY_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNTS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    action: builtins.str
    id: builtins.str
    project: builtins.str
    restore_policy: builtins.str
    @property
    def service_accounts(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def timeouts(self) -> global___ProjectDefaultServiceAccountsXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        id: builtins.str = ...,
        project: builtins.str = ...,
        restore_policy: builtins.str = ...,
        service_accounts: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        timeouts: global___ProjectDefaultServiceAccountsXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "id", b"id", "project", b"project", "resource_info", b"resource_info", "restore_policy", b"restore_policy", "service_accounts", b"service_accounts", "timeouts", b"timeouts"]) -> None: ...

global___ProjectDefaultServiceAccounts = ProjectDefaultServiceAccounts

@typing_extensions.final
class ProjectIamAuditConfigXAuditLogConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXEMPTED_MEMBERS_FIELD_NUMBER: builtins.int
    LOG_TYPE_FIELD_NUMBER: builtins.int
    @property
    def exempted_members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    log_type: builtins.str
    def __init__(
        self,
        *,
        exempted_members: collections.abc.Iterable[builtins.str] | None = ...,
        log_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exempted_members", b"exempted_members", "log_type", b"log_type"]) -> None: ...

global___ProjectIamAuditConfigXAuditLogConfig = ProjectIamAuditConfigXAuditLogConfig

@typing_extensions.final
class ProjectIamAuditConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    AUDIT_LOG_CONFIG_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    project: builtins.str
    service: builtins.str
    @property
    def audit_log_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProjectIamAuditConfigXAuditLogConfig]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        project: builtins.str = ...,
        service: builtins.str = ...,
        audit_log_config: collections.abc.Iterable[global___ProjectIamAuditConfigXAuditLogConfig] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audit_log_config", b"audit_log_config", "etag", b"etag", "id", b"id", "project", b"project", "resource_info", b"resource_info", "service", b"service"]) -> None: ...

global___ProjectIamAuditConfig = ProjectIamAuditConfig

@typing_extensions.final
class ProjectIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ProjectIamBindingXCondition = ProjectIamBindingXCondition

@typing_extensions.final
class ProjectIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___ProjectIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___ProjectIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___ProjectIamBinding = ProjectIamBinding

@typing_extensions.final
class ProjectIamCustomRole(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETED_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_ID_FIELD_NUMBER: builtins.int
    STAGE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    deleted: builtins.bool
    description: builtins.str
    id: builtins.str
    name: builtins.str
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role_id: builtins.str
    stage: builtins.str
    title: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        deleted: builtins.bool = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        permissions: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role_id: builtins.str = ...,
        stage: builtins.str = ...,
        title: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deleted", b"deleted", "description", b"description", "id", b"id", "name", b"name", "permissions", b"permissions", "project", b"project", "resource_info", b"resource_info", "role_id", b"role_id", "stage", b"stage", "title", b"title"]) -> None: ...

global___ProjectIamCustomRole = ProjectIamCustomRole

@typing_extensions.final
class ProjectIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ProjectIamMemberXCondition = ProjectIamMemberXCondition

@typing_extensions.final
class ProjectIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___ProjectIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___ProjectIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___ProjectIamMember = ProjectIamMember

@typing_extensions.final
class ProjectIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info"]) -> None: ...

global___ProjectIamPolicy = ProjectIamPolicy

@typing_extensions.final
class ProjectOrganizationPolicyXBooleanPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENFORCED_FIELD_NUMBER: builtins.int
    enforced: builtins.bool
    def __init__(
        self,
        *,
        enforced: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enforced", b"enforced"]) -> None: ...

global___ProjectOrganizationPolicyXBooleanPolicy = ProjectOrganizationPolicyXBooleanPolicy

@typing_extensions.final
class ProjectOrganizationPolicyXListPolicyXAllow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALL_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    all: builtins.bool
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        all: builtins.bool = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["all", b"all", "values", b"values"]) -> None: ...

global___ProjectOrganizationPolicyXListPolicyXAllow = ProjectOrganizationPolicyXListPolicyXAllow

@typing_extensions.final
class ProjectOrganizationPolicyXListPolicyXDeny(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALL_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    all: builtins.bool
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        all: builtins.bool = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["all", b"all", "values", b"values"]) -> None: ...

global___ProjectOrganizationPolicyXListPolicyXDeny = ProjectOrganizationPolicyXListPolicyXDeny

@typing_extensions.final
class ProjectOrganizationPolicyXListPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INHERIT_FROM_PARENT_FIELD_NUMBER: builtins.int
    SUGGESTED_VALUE_FIELD_NUMBER: builtins.int
    ALLOW_FIELD_NUMBER: builtins.int
    DENY_FIELD_NUMBER: builtins.int
    inherit_from_parent: builtins.bool
    suggested_value: builtins.str
    @property
    def allow(self) -> global___ProjectOrganizationPolicyXListPolicyXAllow: ...
    @property
    def deny(self) -> global___ProjectOrganizationPolicyXListPolicyXDeny: ...
    def __init__(
        self,
        *,
        inherit_from_parent: builtins.bool = ...,
        suggested_value: builtins.str = ...,
        allow: global___ProjectOrganizationPolicyXListPolicyXAllow | None = ...,
        deny: global___ProjectOrganizationPolicyXListPolicyXDeny | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["allow", b"allow", "deny", b"deny"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow", b"allow", "deny", b"deny", "inherit_from_parent", b"inherit_from_parent", "suggested_value", b"suggested_value"]) -> None: ...

global___ProjectOrganizationPolicyXListPolicy = ProjectOrganizationPolicyXListPolicy

@typing_extensions.final
class ProjectOrganizationPolicyXRestorePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_FIELD_NUMBER: builtins.int
    default: builtins.bool
    def __init__(
        self,
        *,
        default: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default", b"default"]) -> None: ...

global___ProjectOrganizationPolicyXRestorePolicy = ProjectOrganizationPolicyXRestorePolicy

@typing_extensions.final
class ProjectOrganizationPolicyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    READ_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    read: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        read: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "read", b"read", "update", b"update"]) -> None: ...

global___ProjectOrganizationPolicyXTimeouts = ProjectOrganizationPolicyXTimeouts

@typing_extensions.final
class ProjectOrganizationPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSTRAINT_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    BOOLEAN_POLICY_FIELD_NUMBER: builtins.int
    LIST_POLICY_FIELD_NUMBER: builtins.int
    RESTORE_POLICY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    constraint: builtins.str
    etag: builtins.str
    id: builtins.str
    project: builtins.str
    update_time: builtins.str
    version: builtins.float
    @property
    def boolean_policy(self) -> global___ProjectOrganizationPolicyXBooleanPolicy: ...
    @property
    def list_policy(self) -> global___ProjectOrganizationPolicyXListPolicy: ...
    @property
    def restore_policy(self) -> global___ProjectOrganizationPolicyXRestorePolicy: ...
    @property
    def timeouts(self) -> global___ProjectOrganizationPolicyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        constraint: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        project: builtins.str = ...,
        update_time: builtins.str = ...,
        version: builtins.float = ...,
        boolean_policy: global___ProjectOrganizationPolicyXBooleanPolicy | None = ...,
        list_policy: global___ProjectOrganizationPolicyXListPolicy | None = ...,
        restore_policy: global___ProjectOrganizationPolicyXRestorePolicy | None = ...,
        timeouts: global___ProjectOrganizationPolicyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["boolean_policy", b"boolean_policy", "list_policy", b"list_policy", "resource_info", b"resource_info", "restore_policy", b"restore_policy", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["boolean_policy", b"boolean_policy", "constraint", b"constraint", "etag", b"etag", "id", b"id", "list_policy", b"list_policy", "project", b"project", "resource_info", b"resource_info", "restore_policy", b"restore_policy", "timeouts", b"timeouts", "update_time", b"update_time", "version", b"version"]) -> None: ...

global___ProjectOrganizationPolicy = ProjectOrganizationPolicy

@typing_extensions.final
class ProjectServiceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    READ_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    read: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        read: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "read", b"read", "update", b"update"]) -> None: ...

global___ProjectServiceXTimeouts = ProjectServiceXTimeouts

@typing_extensions.final
class ProjectService(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLE_DEPENDENT_SERVICES_FIELD_NUMBER: builtins.int
    DISABLE_ON_DESTROY_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    disable_dependent_services: builtins.bool
    disable_on_destroy: builtins.bool
    id: builtins.str
    project: builtins.str
    service: builtins.str
    @property
    def timeouts(self) -> global___ProjectServiceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        disable_dependent_services: builtins.bool = ...,
        disable_on_destroy: builtins.bool = ...,
        id: builtins.str = ...,
        project: builtins.str = ...,
        service: builtins.str = ...,
        timeouts: global___ProjectServiceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disable_dependent_services", b"disable_dependent_services", "disable_on_destroy", b"disable_on_destroy", "id", b"id", "project", b"project", "resource_info", b"resource_info", "service", b"service", "timeouts", b"timeouts"]) -> None: ...

global___ProjectService = ProjectService

@typing_extensions.final
class ProjectUsageExportBucketXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ProjectUsageExportBucketXTimeouts = ProjectUsageExportBucketXTimeouts

@typing_extensions.final
class ProjectUsageExportBucket(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket_name: builtins.str
    id: builtins.str
    prefix: builtins.str
    project: builtins.str
    @property
    def timeouts(self) -> global___ProjectUsageExportBucketXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket_name: builtins.str = ...,
        id: builtins.str = ...,
        prefix: builtins.str = ...,
        project: builtins.str = ...,
        timeouts: global___ProjectUsageExportBucketXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_name", b"bucket_name", "id", b"id", "prefix", b"prefix", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ProjectUsageExportBucket = ProjectUsageExportBucket



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class SccNotificationConfigXStreamingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILTER_FIELD_NUMBER: builtins.int
    filter: builtins.str
    def __init__(
        self,
        *,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> None: ...

global___SccNotificationConfigXStreamingConfig = SccNotificationConfigXStreamingConfig

@typing_extensions.final
class SccNotificationConfigXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___SccNotificationConfigXTimeouts = SccNotificationConfigXTimeouts

@typing_extensions.final
class SccNotificationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORGANIZATION_FIELD_NUMBER: builtins.int
    PUBSUB_TOPIC_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    STREAMING_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    config_id: builtins.str
    description: builtins.str
    id: builtins.str
    name: builtins.str
    organization: builtins.str
    pubsub_topic: builtins.str
    service_account: builtins.str
    @property
    def streaming_config(self) -> global___SccNotificationConfigXStreamingConfig: ...
    @property
    def timeouts(self) -> global___SccNotificationConfigXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        config_id: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        organization: builtins.str = ...,
        pubsub_topic: builtins.str = ...,
        service_account: builtins.str = ...,
        streaming_config: global___SccNotificationConfigXStreamingConfig | None = ...,
        timeouts: global___SccNotificationConfigXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "streaming_config", b"streaming_config", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_id", b"config_id", "description", b"description", "id", b"id", "name", b"name", "organization", b"organization", "pubsub_topic", b"pubsub_topic", "resource_info", b"resource_info", "service_account", b"service_account", "streaming_config", b"streaming_config", "timeouts", b"timeouts"]) -> None: ...

global___SccNotificationConfig = SccNotificationConfig

@typing_extensions.final
class SccSourceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___SccSourceXTimeouts = SccSourceXTimeouts

@typing_extensions.final
class SccSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORGANIZATION_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    display_name: builtins.str
    id: builtins.str
    name: builtins.str
    organization: builtins.str
    @property
    def timeouts(self) -> global___SccSourceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        organization: builtins.str = ...,
        timeouts: global___SccSourceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "display_name", b"display_name", "id", b"id", "name", b"name", "organization", b"organization", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___SccSource = SccSource



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_codestar.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61ws/aws_codestar.proto\x12\x18oak9.tython.aws.codestar\x1a\x13shared/shared.proto\"\x82\x01\n\x12GitHubRepositoryS3\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eobject_version\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\"\x89\x01\n\x14GitHubRepositoryCode\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x38\n\x02s3\x18\x02 \x01(\x0b\x32,.oak9.tython.aws.codestar.GitHubRepositoryS3\"\xa8\x02\n\x10GitHubRepository\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\renable_issues\x18\x02 \x01(\x08\x12\x17\n\x0frepository_name\x18\x03 \x01(\t\x12\x1f\n\x17repository_access_token\x18\x04 \x01(\t\x12\x18\n\x10repository_owner\x18\x05 \x01(\t\x12\x12\n\nis_private\x18\x06 \x01(\x08\x12<\n\x04\x63ode\x18\x07 \x01(\x0b\x32..oak9.tython.aws.codestar.GitHubRepositoryCode\x12\x1e\n\x16repository_description\x18\x08 \x01(\t\"R\n\x08\x43odeStar\x12\x46\n\x12git_hub_repository\x18\x01 \x03(\x0b\x32*.oak9.tython.aws.codestar.GitHubRepositoryb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_codestar_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GITHUBREPOSITORYS3._serialized_start=74
  _GITHUBREPOSITORYS3._serialized_end=204
  _GITHUBREPOSITORYCODE._serialized_start=207
  _GITHUBREPOSITORYCODE._serialized_end=344
  _GITHUBREPOSITORY._serialized_start=347
  _GITHUBREPOSITORY._serialized_end=643
  _CODESTAR._serialized_start=645
  _CODESTAR._serialized_end=727
# @@protoc_insertion_point(module_scope)
